@@ -64,10 +64,6 @@ class Logger(object):
 
         # check if there's a handler by this name
         if handler_name in self._handlers:
-
-            # log that we're removing it
-            self.info_with("Replacing logger output", handler_name=handler_name)
-
             self._logger.removeHandler(self._handlers[handler_name])
 
         # create a stream handler from the file
